==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_timeinterval.js <==
_me = obj_timeinterval.prototype;
function obj_timeinterval(){};

_me.__constructor = function(bWithAllDay) {
	var me = this;
    this.nMillisecondsPerDay = 86400000;//24 * 3600000;

	this.startDate._ondateselect = function() { me.__checkIfEndTimeIsGreaterThanStartTime();
	me.__computeDuration();
	}
	this.endDate._ondateselect = function() { me.__checkIfStartTimeIsLessThanEndTime();
	me.__computeDuration();
	}
	
	this.startTime._onchange = function() {	me.__checkIfEndTimeIsGreaterThanStartTime();
	me.__computeDuration();
	}
	this.endTime._onchange = function() { me.__checkIfStartTimeIsLessThanEndTime();
	me.__computeDuration();
	}


	this.durationDays._onkeyup = function() {
		//blank to 0
		if (this._value() === '') this._value(0,true);
		me.__setEndTimeFromDuration();
	};
	
	this.durationDays._onkeydown = function(e){
		// 01 format is not allowed
		var key = e.keyCode;

		if (key>46 && key<58) key+=48;

		if (this._value() == 0){
			if (key==96)
				return false;
			else
			if (key>96 && key<106){
			    this._value(key-96,true);
			    return false;
			}
		}

		if((key>95 && key<106) || (key>36 && key<41) || key == 8 || key == 46 || key == 16)
		    return true;
		else
		    return false;
	};
	
	this.durationTime._onchange = function() { me.__setEndTimeFromDuration(); }

	if (bWithAllDay === true || bWithAllDay == 'true') {
	    this._create('allDay', 'obj_checkbox', 'all_day');
	    this.allDay._title('TIME_INTERVAL::ALL_DAY_EVENT');
	    this.allDay._onclick = function() { me.__disableOrEnableDuration(me.__allDayEvent()); me.__computeDuration(); }
	}
};

_me.__allDayEvent = function() {
	return Is.Defined(this.allDay) && this.allDay._value();
};

_me._value = function(aValues) {

	if (Is.Defined(aValues)) {
	    if (Is.Defined(aValues['EVNSTARTDATE']) && aValues['EVNSTARTDATE'] != 'undefined') this.startDate._value(aValues['EVNSTARTDATE']);

		if (Is.Defined(aValues['EVNSTARTTIME']) && aValues['EVNSTARTTIME'] != 'undefined' && aValues['EVNSTARTTIME'] != '-1') {
			if (Is.Defined(aValues['EVNENDDATE']) && aValues['EVNENDDATE'] != 'undefined') this.endDate._value(aValues['EVNENDDATE']);
			this.startTime._value(aValues['EVNSTARTTIME']*60000, true);
			this.__disableOrEnableDuration(false);
		}
		else {
			if (Is.Defined(aValues['EVNENDDATE']) && aValues['EVNENDDATE'] != 'undefined') this.endDate._value(aValues['EVNENDDATE']-1);
		    this.startTime._value(0, true);
			if (Is.Defined(this.allDay)){
				this.allDay._value(true);
				this.__disableOrEnableDuration(true);
			}
		}

		if (Is.Defined(aValues['EVNENDTIME']) && aValues['EVNENDTIME'] != 'undefined' && aValues['EVNENDTIME'] != '-1')
			this.endTime._value(aValues['EVNENDTIME']*60000, true);
		else
		    this.endTime._value(0, true);

		this.__computeDuration();
	}
	else {
	    var aReturn = {};
	    aReturn['EVNSTARTDATE'] = this.startDate._value();
	    aReturn['EVNENDDATE'] = this.endDate._value();

  		if (this.__allDayEvent()) {
			aReturn['EVNSTARTTIME'] = -1;
			aReturn['EVNENDTIME'] = -1;
			aReturn['EVNENDDATE']++;
		} else {
			aReturn['EVNSTARTTIME'] = this.startTime._value()/60000;
			aReturn['EVNENDTIME'] = this.endTime._value()/60000;
		}
		return aReturn;
	}
};

_me.__setEndTimeFromDuration = function() {

	var days = parseInt(this.durationDays._value());

	if (!isNaN(days)) {
		if (this.__allDayEvent()) {
			if (days >= 1) {
				this.__addDateAndTime(days-1, this.durationTime._value());
				return;
			}
		}
		else {
			if (days >= 0) {
				this.__addDateAndTime(days, this.durationTime._value());
				return;
			}
		}
	}
	this.__addDateAndTime(0, this.durationTime._value());
};

//End
_me.__checkIfStartTimeIsLessThanEndTime = function() {
	if ((this.startTime._value() + (this.startDate._getObjectDate().getTime())) >
		(this.endTime._value() + (this.endDate._getObjectDate().getTime()))) {

		this.startTime._value(this.endTime._value(), true);
		this.startDate._value(this.endDate._value());
	}
};
//Start
_me.__checkIfEndTimeIsGreaterThanStartTime = function() {
	if ((this.startTime._value() + (this.startDate._getObjectDate().getTime())) >
		(this.endTime._value() + (this.endDate._getObjectDate().getTime()))) {

		this.endTime._value(this.startTime._value(), true);
		this.endDate._value(this.startDate._value());
	}
};

_me.__addDateAndTime = function(nDays, nMillisecondsTime) {

	var nTime = this.startTime._value() + nMillisecondsTime;
	if (nTime >= this.nMillisecondsPerDay) {
		nDays++;
		nTime %= this.nMillisecondsPerDay;
	}

	this.endDate._value(new Date(this.startDate._getObjectDate().getTime() + nDays*this.nMillisecondsPerDay));
	this.endTime._value(nTime, true);
};

_me.__computeDuration = function() {

    var iDay = this.endDate._value() - this.startDate._value();
	var iTime = this.endTime._value() - this.startTime._value();
	if (iTime<0){
		iTime += 86400000;
		iDay--;
	}
	this.durationDays._value(iDay,true);
	this.durationTime._value(iTime, true);
};

_me.__disableOrEnableDuration = function(bDisable) {
	this.startTime._disabled(bDisable);
	this.endTime._disabled(bDisable);
	this.durationTime._disabled(bDisable);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_timeinterval.js <==
_me = obj_timeinterval.prototype;
function obj_timeinterval(){};

_me.__constructor = function(bWithAllDay) {
	var me = this;
    this.nMillisecondsPerDay = 86400000;//24 * 3600000;

	this.startDate._ondateselect = function() { me.__checkIfEndTimeIsGreaterThanStartTime();
	me.__computeDuration();
	}
	this.endDate._ondateselect = function() { me.__checkIfStartTimeIsLessThanEndTime();
	me.__computeDuration();
	}
	
	this.startTime._onchange = function() {	me.__checkIfEndTimeIsGreaterThanStartTime();
	me.__computeDuration();
	}
	this.endTime._onchange = function() { me.__checkIfStartTimeIsLessThanEndTime();
	me.__computeDuration();
	}


	this.durationDays._onkeyup = function() {
		//blank to 0 (or 1 in case of All Day)
		if (this._value()==='' || this._value()=='0')
			this._value(me.__allDayEvent()?1:0,true);
			
		me.__setEndTimeFromDuration();
	};
	
	this.durationDays._onkeydown = function(e){
		// 01 format is not allowed
		var key = e.keyCode;

		if (key>46 && key<58) key+=48;

		if (this._value() == 0){
			if (key==96)
				return false;
			else
			if (key>96 && key<106){
			    this._value(key-96,true);
			    return false;
			}
		}

		if((key>95 && key<106) || (key>36 && key<41) || key == 8 || key == 46 || key == 16)
		    return true;
		else
		    return false;
	};

	this.durationTime._onchange = function() { me.__setEndTimeFromDuration(); }

	if (bWithAllDay === true || bWithAllDay == 'true') {
		this._create('allDay', 'obj_checkbox', 'all_day');

		this.allDay._title('TIME_INTERVAL::ALL_DAY_EVENT');
		this.allDay._onclick = function() {
			me.__disableOrEnableDuration(me.__allDayEvent());
			me.__computeDuration();
		};

		this.allDay._onchange = function (){
			if (this._value()){
				me.endTime._value(0,true);
				me.startTime._value(0,true);
				me.__computeDuration();
			}
			else{
				me.__computeDuration();
				var tmp = (me.durationDays._value()*1) + (me.durationTime._value()*1);
				if (!this._value() && !tmp){
					var sTime = GWOthers.getItem('CALENDAR_SETTINGS','day_begins')*3600000;
					me.startTime._value(sTime==NaN?0:sTime,true);
					me.durationTime._value(1800000);
				}
			}
		};
	}
};

_me.__allDayEvent = function() {
	return Is.Defined(this.allDay) && this.allDay._value();
};

_me._value = function(aValues) {

	if (Is.Defined(aValues)) {

		if (Is.Defined(aValues['EVNSTARTDATE']) && aValues['EVNSTARTDATE'] != 'undefined')
			this.startDate._value(aValues['EVNSTARTDATE']);

		if (Is.Defined(aValues['EVNSTARTTIME']) && aValues['EVNSTARTTIME'] != 'undefined' && aValues['EVNSTARTTIME'] > -1) {
			if (Is.Defined(aValues['EVNENDDATE']) && aValues['EVNENDDATE'] != 'undefined') this.endDate._value(aValues['EVNENDDATE']);
			this.startTime._value(aValues['EVNSTARTTIME']*60000, true);

			if (Is.Defined(this.allDay)){
				this.allDay._value(false);
				this.__disableOrEnableDuration(false);
			}
		}
		else {
			if (Is.Defined(aValues['EVNENDDATE']) && aValues['EVNENDDATE'] != 'undefined')
				this.endDate._value(aValues['EVNENDDATE']-1);

			this.startTime._value(0, true);
			if (Is.Defined(this.allDay)){
				this.allDay._value(true);
				this.__disableOrEnableDuration(true);
			}
		}

		if (Is.Defined(aValues['EVNENDTIME']) && aValues['EVNENDTIME'] != 'undefined' && aValues['EVNENDTIME'] > -1)
			this.endTime._value(aValues['EVNENDTIME']*60000, true);
		else
			this.endTime._value(0, true);

		this.__computeDuration();
	}
	else {
		var aReturn = {};
		aReturn['EVNSTARTDATE'] = this.startDate._value();
		aReturn['EVNENDDATE'] = this.endDate._value();

		if (this.__allDayEvent()) {
			aReturn['EVNSTARTTIME'] = -1;
			aReturn['EVNENDTIME'] = -1;
			aReturn['EVNENDDATE']++;
		} else {
			aReturn['EVNSTARTTIME'] = this.startTime._value()/60000;
			aReturn['EVNENDTIME'] = this.endTime._value()/60000;
		}
		return aReturn;
	}
};

_me.__setEndTimeFromDuration = function() {

	var days = parseInt(this.durationDays._value());

	if (!isNaN(days)) {
		if (this.__allDayEvent()) {
			if (days >= 1) {
				this.__addDateAndTime(days-1, this.durationTime._value());
				return;
			}
		}
		else {
			if (days >= 0) {
				this.__addDateAndTime(days, this.durationTime._value());
				return;
			}
		}
	}
	this.__addDateAndTime(0, this.durationTime._value());
};

//End
_me.__checkIfStartTimeIsLessThanEndTime = function() {
	if ((this.startTime._value() + (this.startDate._getObjectDate().getTime())) >
		(this.endTime._value() + (this.endDate._getObjectDate().getTime()))) {

		this.startTime._value(this.endTime._value(), true);
		this.startDate._value(this.endDate._value());
	}
};
//Start
_me.__checkIfEndTimeIsGreaterThanStartTime = function() {
	if ((this.startTime._value() + (this.startDate._getObjectDate().getTime())) >=
		(this.endTime._value() + (this.endDate._getObjectDate().getTime()))) {

		this.endTime._value((this.startTime._value()*1)+(this.durationTime._value()*1), true);
		this.endDate._value((this.startDate._value()*1)+(this.durationDays._value()*1));
	}
};

_me.__addDateAndTime = function(nDays, nMillisecondsTime) {

	var nTime = this.startTime._value() + nMillisecondsTime;
	if (nTime >= this.nMillisecondsPerDay) {
		nDays++;
		nTime %= this.nMillisecondsPerDay;
	}

	this.endDate._value(new Date(this.startDate._getObjectDate().getTime() + nDays*this.nMillisecondsPerDay));
	this.endTime._value(nTime, true);

	//ONCHANGE EVENT
	if (this._onchange)
		this._onchange();
};

_me.__computeDuration = function() {

	var iDay = this.endDate._value() - this.startDate._value();

	if (this.__allDayEvent())
		iDay++;
	else{
		var iTime = this.endTime._value() - this.startTime._value();
		if (iTime<0){
			iTime += 86400000;
			iDay--;
		}
		this.durationTime._value(iTime, true);
	}

	this.durationDays._value(iDay,true);

	//ONCHANGE EVENT
	if (this._onchange)
	    this._onchange();
};

_me.__disableOrEnableDuration = function(bDisable) {
	this.startTime._disabled(bDisable);
	this.endTime._disabled(bDisable);
	this.durationTime._disabled(bDisable);
	//this.allDay(bDisable);
};
